# fasttracks

[![arXiv](https://img.shields.io/badge/arXiv-2411.18370-b31b1b.svg)](https://arxiv.org/abs/2411.18370)

A massively-parallel engine to evaluate detection statistics for generic CW signals.

## Citing this work

If `fasttracks` was useful to your research, we would appreciate if you cited
[Tenorio+ (2024)](https://arxiv.org/abs/2411.18370) where this
implementation was first presented:
```
@article{Tenorio:2024jgc,
    author = "Tenorio, Rodrigo and M\'erou, Joan-Ren\'e and Sintes, Alicia M.",
    title = "{A one-stop strategy to search for long-duration gravitational-wave signals}",
    eprint = "2411.18370",
    archivePrefix = "arXiv",
    primaryClass = "gr-qc",
    reportNumber = "LIGO-P2400425",
    month = "11",
    year = "2024",
    journal = "arXiv e-prints"
}
```
as well as a Zenodo release of this software.
